#!/usr/bin/env python
import sqlite3
import argparse
import os
import sys
import re

def _rename_base_path(library, new, old):
    conn = sqlite3.connect(library)
    cur = conn.cursor()
    ret = cur.execute("""select id, folder from film_rolls""")

    cnt = 0
    for elem in ret.fetchall():
        new_folder = elem[1].replace(old, new)
        cur.execute("""update film_rolls set folder='%s' where id='%s'""" %
            (new_folder, elem[0]))
        cnt += 1

    conn.commit()
    return cnt

def main():
    parser = argparse.ArgumentParser(description='Rename film roll paths')
    parser.add_argument('--library',
        default='~/.config/darktable/library.db',
        help='path to darktable library')
    parser.add_argument('-o', '--old', required=True,
        help='old image base dir e.g. /home/chris/Photos')
    parser.add_argument('-n', '--new', required=True,
        help='new photo base dir e.g. /media/EXTERNAL/Photos2011')
    
    args = parser.parse_args()
    library_path = os.path.expanduser(args.library)
    new_dir = re.sub(r'/$', '', os.path.expanduser(args.new))
    old_dir = re.sub(r'/$', '', os.path.expanduser(args.old))
    if not os.path.isfile(library_path):
        print("No such file %s" % library_path)
        sys.exit(1)
    if not os.path.isdir(new_dir):
        print("No such directory %s" % new_dir)
        sys.exit(1)
    if new_dir == old_dir:
        print("No need to change anyhting")
        sys.exit(1)

    print("Make sure darktable is currently not running")
    msg = "Continue? (y/n) "
    try:
        # python2
        cont = raw_input(msg)
    except NameError:
        # python3
        cont = input(msg)
    if cont == 'y':
        ret = _rename_base_path(library_path, new_dir, old_dir)
        print("Renamed %s film rolls from %s to %s" % (ret, old_dir, new_dir))
    else:
        print("Aborted")
        sys.exit(2)

if __name__ == '__main__':
    main()
